pub struct AssetSourceBuilders { /* private fields */ }Expand description
A Resource that hold (repeatable) functions capable of producing new AssetReader and AssetWriter instances
for a given asset source.
Implementations
Sourceimpl AssetSourceBuilders
impl AssetSourceBuilders
Sourcepub fn insert(
&mut self,
id: impl Into<AssetSourceId<'static>>,
source: AssetSourceBuilder,
)
pub fn insert( &mut self, id: impl Into<AssetSourceId<'static>>, source: AssetSourceBuilder, )
Inserts a new builder with the given id
Sourcepub fn get_mut<'a, 'b>(
&'a mut self,
id: impl Into<AssetSourceId<'b>>,
) -> Option<&'a mut AssetSourceBuilder>
pub fn get_mut<'a, 'b>( &'a mut self, id: impl Into<AssetSourceId<'b>>, ) -> Option<&'a mut AssetSourceBuilder>
Gets a mutable builder with the given id, if it exists.
Sourcepub fn build_sources(
&mut self,
watch: bool,
watch_processed: bool,
) -> AssetSources
pub fn build_sources( &mut self, watch: bool, watch_processed: bool, ) -> AssetSources
Builds a new AssetSources collection. If watch is true, the unprocessed sources will watch for changes.
If watch_processed is true, the processed sources will watch for changes.
Sourcepub fn init_default_source(&mut self, path: &str, processed_path: Option<&str>)
pub fn init_default_source(&mut self, path: &str, processed_path: Option<&str>)
Initializes the default AssetSourceBuilder if it has not already been set.